==> balsa-2.4.7-i486-1gsb.txz: install/doinst.sh <==
( cd usr/share/balsa/hicolor ; rm -rf 22x22 )
( cd usr/share/balsa/hicolor ; ln -sf 24x24 22x22 )
( cd usr/share/gnome/help/balsa/C/figures ; rm -rf address-book-start.png )
( cd usr/share/gnome/help/balsa/C/figures ; ln -sf ../../C/figures/address-book-start.png address-book-start.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/figuresdobaaddress-book-modify.png figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf main-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/main-window.png main-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf message-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/message-window.png message-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf address-book-start.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/address-book-start.png address-book-start.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf newmsg-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/newmsg-window.png newmsg-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/main-window-toolbar.png main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf address-book.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/address-book.png address-book.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf address-book-ldap.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/address-book-ldap.png address-book-ldap.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf msg-part-select.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/msg-part-select.png msg-part-select.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf example-alias.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/example-alias.png example-alias.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf balsa_logo.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/balsa_logo.png balsa_logo.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf preferences-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/preferences-window.png preferences-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf address-book-vcard.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/address-book-vcard.png address-book-vcard.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf spell-check.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/spell-check.png spell-check.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/newmsg-window-attachments.png newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/newmsg-window-toolbar.png newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf address-book-modify.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/address-book-modify.png address-book-modify.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/figuresdobaaddress-book-modify.png figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf main-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/main-window.png main-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf message-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/message-window.png message-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf address-book-start.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/address-book-start.png address-book-start.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf newmsg-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/newmsg-window.png newmsg-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/main-window-toolbar.png main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf address-book.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/address-book.png address-book.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf address-book-ldap.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/address-book-ldap.png address-book-ldap.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf msg-part-select.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/msg-part-select.png msg-part-select.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf example-alias.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/example-alias.png example-alias.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf balsa_logo.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/balsa_logo.png balsa_logo.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf preferences-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/preferences-window.png preferences-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf address-book-vcard.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/address-book-vcard.png address-book-vcard.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf spell-check.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/spell-check.png spell-check.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf druid-start.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/druid-start.png druid-start.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/newmsg-window-attachments.png newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/newmsg-window-toolbar.png newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf address-book-modify.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/address-book-modify.png address-book-modify.png )

# update rarian database
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop database
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

==> balsa-2.4.9-i486-2gsb.txz: install/doinst.sh <==
( cd usr/share/balsa/hicolor ; rm -rf 22x22 )
( cd usr/share/balsa/hicolor ; ln -sf 24x24 22x22 )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf example-alias.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/example-alias.png example-alias.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/newmsg-window-toolbar.png newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf message-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/message-window.png message-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf spell-check.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/spell-check.png spell-check.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/main-window-toolbar.png main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/newmsg-window-attachments.png newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/figuresdobaaddress-book-modify.png figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf msg-part-select.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/msg-part-select.png msg-part-select.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf address-book.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/address-book.png address-book.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf newmsg-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/newmsg-window.png newmsg-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf balsa_logo.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/balsa_logo.png balsa_logo.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf preferences-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/preferences-window.png preferences-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf address-book-modify.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/address-book-modify.png address-book-modify.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf main-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/main-window.png main-window.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf address-book-ldap.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/address-book-ldap.png address-book-ldap.png )
( cd usr/share/gnome/help/balsa/de/figures ; rm -rf address-book-vcard.png )
( cd usr/share/gnome/help/balsa/de/figures ; ln -sf ../../C/figures/address-book-vcard.png address-book-vcard.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf example-alias.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/example-alias.png example-alias.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf druid-start.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/druid-start.png druid-start.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/newmsg-window-toolbar.png newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf message-window.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/message-window.png message-window.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf spell-check.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/spell-check.png spell-check.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/main-window-toolbar.png main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/newmsg-window-attachments.png newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/figuresdobaaddress-book-modify.png figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf msg-part-select.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/msg-part-select.png msg-part-select.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf address-book.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/address-book.png address-book.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf newmsg-window.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/newmsg-window.png newmsg-window.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf balsa_logo.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/balsa_logo.png balsa_logo.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf preferences-window.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/preferences-window.png preferences-window.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf address-book-modify.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/address-book-modify.png address-book-modify.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf main-window.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/main-window.png main-window.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf address-book-ldap.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/address-book-ldap.png address-book-ldap.png )
( cd usr/share/gnome/help/balsa/sl/figures ; rm -rf address-book-vcard.png )
( cd usr/share/gnome/help/balsa/sl/figures ; ln -sf ../../C/figures/address-book-vcard.png address-book-vcard.png )
( cd usr/share/gnome/help/balsa/fr/figures ; rm -rf example-alias.png )
( cd usr/share/gnome/help/balsa/fr/figures ; ln -sf ../../C/figures/example-alias.png example-alias.png )
( cd usr/share/gnome/help/balsa/fr/figures ; rm -rf figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/fr/figures ; ln -sf ../../C/figures/figuresdobaaddress-book-modify.png figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/fr/figures ; rm -rf balsa_logo.png )
( cd usr/share/gnome/help/balsa/fr/figures ; ln -sf ../../C/figures/balsa_logo.png balsa_logo.png )
( cd usr/share/gnome/help/balsa/fr/figures ; rm -rf preferences-window.png )
( cd usr/share/gnome/help/balsa/fr/figures ; ln -sf ../../C/figures/preferences-window.png preferences-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf example-alias.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/example-alias.png example-alias.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf druid-start.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/druid-start.png druid-start.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/newmsg-window-toolbar.png newmsg-window-toolbar.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf message-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/message-window.png message-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf spell-check.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/spell-check.png spell-check.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/main-window-toolbar.png main-window-toolbar.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/newmsg-window-attachments.png newmsg-window-attachments.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/figuresdobaaddress-book-modify.png figuresdobaaddress-book-modify.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf msg-part-select.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/msg-part-select.png msg-part-select.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf address-book.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/address-book.png address-book.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf newmsg-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/newmsg-window.png newmsg-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf balsa_logo.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/balsa_logo.png balsa_logo.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf preferences-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/preferences-window.png preferences-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf address-book-modify.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/address-book-modify.png address-book-modify.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf main-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/main-window.png main-window.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf address-book-ldap.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/address-book-ldap.png address-book-ldap.png )
( cd usr/share/gnome/help/balsa/es/figures ; rm -rf address-book-vcard.png )
( cd usr/share/gnome/help/balsa/es/figures ; ln -sf ../../C/figures/address-book-vcard.png address-book-vcard.png )
